##  Turning Off Import Rules
To temporarily turn off an import rule, do the following:
  1. In the administration area of SAP LeanIX, go to Integrations > Atlassian Jira and select the integration instance.
  2. On the Import Rules tab, toggle the switch next to the rule you want to turn off.


Turning Import Rules On or Off
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio1aa07236cad1411491001d37e22a5e8b_LowRes.png)
